# TarcisiobragsTads

Este é um projeto desenvolvido para  demostrar aos estudantes o uso e a aplicação de bibliotecas (gem) para o encapsulamento funcionalidades genéricas que podem ser utilizadas em outros projetos. Outro objetivo atrelado a esta atividade relaciona-se ao conteúdo teórico sobre ORM (Mapeamento Objeto Relacional), os quais foram apresentados em aulas de Tópicos Especiais em Tecnologia da Informação no Institulo Federal de Mato Grosso do Sul, Campus de Naviraí, e são aplicados de forma prática neste.

## Instalação

Caso use um arquivo Gemfile, baixado manualmente adicione o código abaixo:

```ruby
gem 'tarcisiobrags_tads'
```

Logo após instale as dependências:

    $ bundle install

Ou, instale diretamente a gem executando o código abaixo em seu terminal:

    $ gem install tarcisiobrags_tads

## Como utilizar

Para utilizar a `gem` deve-se realizar os seguintes passos:

Primeiro crie um novo arquivo e adicione uma classe a qual você deseja persistir seguindo as especificações abaixo:

```ruby
# Require necessário
require 'tarcisiobrags_tads'

# Sua classe deve herdar a classe TarcisiobragsTads::ORM
class ExemploClasse < TarcisiobragsTads::ORM
  # Toda classe deve conter um :ID obrigatoriamente
  attr_accessor :id, :modelo

  # O construtor deve seguir o exemplo abaixo
  def initialize(hash)
    @titulo = hash.first[:modelo]
  end

  # Este método deve ser reescrito obrigatoriamente com o
  # caminho para seu banco de dados 'db/nomeclasseminúsculo'
  def self.path
    'local/onde/deseja/salvar/os/dados'
  end
end
```
## Passo a Passo

Crie o diretório com o caminho especificado no método `self.path`

### Criar um novo registro:
```ruby
ExemploClasse.criar(
  modelo: 'Fusca 5000'
)
```

### Listar todos os registros:
```ruby
puts ExemploClasse.listar
```

### Selecionar um registro específico
```ruby
puts ExemploClasse.selecionar(1)
```

### Atualizar um registro específico
```ruby
carro = ExemploClasse.selecionar(1)
carro.modelo = "novo modelo"
ExemploClasse.atualizar(carro)
```

### Remover um registro específico
```ruby
ExemploClasse.remove(1)
```
## Importante

 - O atributo id deve estar contido, contudo ele não deve ser inicializado.
 - O método path obrigatoriamente deve ser reescrito para o local onde você deseja salvar os dados

```ruby
  def self.path
    'local/onde/deseja/salvar/os/dados'
  end
```

## Licença

A gem está disponível como código aberto sob os termos do [MIT License](https://opensource.org/licenses/MIT).

## Código de Conduta

Espera-se que todos que interagem nas bases de código do projeto TarcisiobragsTads, rastreadores de problemas, salas de bate-papo e listas de discussão sigam as [code of conduct](https://github.com/[USERNAME]/tarcisiobrags_tads/blob/master/CODE_OF_CONDUCT.md).
